@@ -13,10 +13,10 @@
 #ifndef _LESS_TRIVIAL_SYNTH_QT_GUI_H_INCLUDED_
 #define _LESS_TRIVIAL_SYNTH_QT_GUI_H_INCLUDED_
 
-#include <qframe.h>
-#include <qdial.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QFrame>
+#include <QDial>
+#include <QLabel>
+#include <QLayout>
 
 extern "C" {
 #include <lo/lo.h>
@@ -27,9 +27,9 @@ class SynthGUI : public QFrame
     Q_OBJECT
 
 public:
-    SynthGUI(QString host, QString port,
-	     QString controlPath, QString midiPath, QString programPath,
-	     QString exitingPath, QWidget *w = 0);
+    SynthGUI(const char * host, const char * port,
+	     QByteArray controlPath, QByteArray midiPath, QByteArray programPath,
+	     QByteArray exitingPath, QWidget *w = 0);
     virtual ~SynthGUI();
 
     bool ready() const { return m_ready; }
@@ -58,6 +58,8 @@ protected slots:
     void oscRecv();
 
 protected:
+    QDial *newQDial( int, int, int, int );
+    
     QDial *m_tuning;
     QDial *m_attack;
     QDial *m_decay;
@@ -73,10 +75,10 @@ protected:
     QLabel *m_timbreLabel;
 
     lo_address m_host;
-    QString m_controlPath;
-    QString m_midiPath;
-    QString m_programPath;
-    QString m_exitingPath;
+    QByteArray m_controlPath;
+    QByteArray m_midiPath;
+    QByteArray m_programPath;
+    QByteArray m_exitingPath;
 
     bool m_suppressHostUpdate;
     bool m_hostRequestedQuit;
